@@ -28,11 +28,11 @@ pub struct Packet {
 }
 
 impl Packet {
-    pub fn from_rxpk(rxpk: RxPk) -> Packet {
+    pub fn from_rxpk(gateway_mac: MacAddress, rxpk: RxPk) -> Packet {
         let rxpk = vec![rxpk];
         Packet {
             random_token: 0,
-            gateway_mac: MacAddress::from([0; 8]),
+            gateway_mac,
             data: Data {
                 rxpk: Some(rxpk),
                 stat: None,
@@ -40,6 +40,17 @@ impl Packet {
         }
     }
 
+    pub fn from_stat(gateway_mac: MacAddress, stat: Stat) -> Packet {
+        Packet {
+            random_token: 0,
+            gateway_mac,
+            data: Data {
+                rxpk: None,
+                stat: Some(stat),
+            },
+        }
+    }
+
     pub fn random() -> Packet {
         let rxpk = vec![RxPk::V1(RxPkV1 {
             chan: 0,
@@ -325,7 +336,7 @@ pub struct Stat {
     #[serde(skip_serializing_if = "Option::is_none")]
     long: Option<f64>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    alti: Option<u64>,
+    alti: Option<i64>,
     rxnb: u64,
     rxok: u64,
     rxfw: u64,
